/*
 * Steganography utility to hide messages into cover files
 * Author: Samir Vaidya (mailto:syvaidya@gmail.com)
 * Copyright (c) 2007-2008 Samir Vaidya
 */

package net.sourceforge.openstego.plugin.template.dct;

import java.util.Map;

import net.sourceforge.openstego.OpenStegoConfig;
import net.sourceforge.openstego.OpenStegoException;
import net.sourceforge.openstego.util.CmdLineOptions;

/**
 * Class to store configuration data for DCT plugin template
 */
public class DCTConfig extends OpenStegoConfig
{
    /**
     * Image file extension to use for writing
     */
    private String imageFileExtension = "png";

    /**
     * Default Constructor (with default values for configuration items)
     */
    public DCTConfig()
    {
    }

    /**
     * Constructor with map of configuration data. Please make sure that only valid keys for configuration
     * items are provided, and the values for those items are also valid.
     * @param propMap Map containing the configuration data
     * @throws OpenStegoException
     */
    public DCTConfig(Map propMap) throws OpenStegoException
    {
        addProperties(propMap);
    }

    /**
     * Constructor which reads configuration data from the command line options.
     * @param options Command-line options
     * @throws OpenStegoException
     */
    public DCTConfig(CmdLineOptions options) throws OpenStegoException
    {
        super(options);
    }

    /**
     * Method to add properties from the map to this configuration data
     * @param propMap Map containing the configuration data
     * @throws OpenStegoException
     */
    protected void addProperties(Map propMap) throws OpenStegoException
    {
        super.addProperties(propMap);
    }

    /**
     * Get method for configuration item - imageFileExtension
     * @return imageFileExtension
     */
    public String getImageFileExtension()
    {
        return imageFileExtension;
    }

    /**
     * Set method for configuration item - imageFileExtension
     * @param imageFileExtension
     */
    public void setImageFileExtension(String imageFileExtension)
    {
        this.imageFileExtension = imageFileExtension;
    }
}
